"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SettingsCategoryAppearance = void 0;
const react_1 = __importDefault(require("react"));
const react_redux_1 = require("react-redux");
const useUpdate_1 = __importDefault(require("react-use/lib/useUpdate"));
const os_1 = __importDefault(require("os"));
const data_1 = require("../../../data/data");
const settings_key_1 = require("../../../data/settings-key");
const utils_1 = require("../../../bchat/utils");
const modalDialog_1 = require("../../../state/ducks/modalDialog");
const userConfig_1 = require("../../../state/ducks/userConfig");
const userConfig_2 = require("../../../state/selectors/userConfig");
const BchatButton_1 = require("../../basic/BchatButton");
const BchatSettingListItem_1 = require("../BchatSettingListItem");
const ZoomingBchatSlider_1 = require("../ZoomingBchatSlider");
const BchatTheme_1 = require("../../../state/ducks/BchatTheme");
const theme_1 = require("../../../state/ducks/theme");
async function toggleStartInTray() {
    try {
        const newValue = !(await window.getStartInTray());
        window.setSettingValue(settings_key_1.SettingsKey.settingsStartInTray, newValue);
        await window.setStartInTray(newValue);
        if (!newValue) {
            utils_1.ToastUtils.pushRestartNeeded();
        }
    }
    catch (e) {
        window.log.warn('start in tray change error:', e);
    }
}
const SettingsCategoryAppearance = (props) => {
    const dispatch = (0, react_redux_1.useDispatch)();
    const forceUpdate = (0, useUpdate_1.default)();
    const audioAutoPlay = (0, react_redux_1.useSelector)(userConfig_2.getAudioAutoplay);
    const darktheme = (0, react_redux_1.useSelector)((state) => state.theme);
    if (props.hasPassword !== null) {
        const isdark = darktheme === "dark" ? true : false;
        const isSpellCheckActive = window.getSettingValue(settings_key_1.SettingsKey.settingsSpellCheck) === undefined
            ? true
            : window.getSettingValue(settings_key_1.SettingsKey.settingsSpellCheck);
        const isLinkPreviewsOn = Boolean(window.getSettingValue(settings_key_1.SettingsKey.settingsLinkPreview));
        const isStartInTrayActive = Boolean(window.getSettingValue(settings_key_1.SettingsKey.settingsStartInTray));
        function handleClick() {
            const themeFromSettings = window.Events.getThemeSetting();
            const updatedTheme = themeFromSettings === 'dark' ? 'light' : 'dark';
            dispatch((0, theme_1.applyTheme)(updatedTheme));
            window.setTheme(updatedTheme);
            if (updatedTheme === 'dark') {
                (0, BchatTheme_1.switchHtmlToDarkTheme)();
            }
            else {
                (0, BchatTheme_1.switchHtmlToLightTheme)();
            }
        }
        async function toggleLinkPreviews() {
            const newValue = !window.getSettingValue(settings_key_1.SettingsKey.settingsLinkPreview);
            if (!newValue) {
                window.setSettingValue(settings_key_1.SettingsKey.settingsLinkPreview, newValue);
                await (0, data_1.createOrUpdateItem)({ id: data_1.hasLinkPreviewPopupBeenDisplayed, value: false });
            }
            else {
                window.inboxStore?.dispatch((0, modalDialog_1.updateConfirmModal)({
                    title: window.i18n('linkPreviewsTitle'),
                    message: window.i18n('linkPreviewsConfirmMessage'),
                    okTheme: BchatButton_1.BchatButtonColor.Danger,
                    onClickOk: () => {
                        window.setSettingValue(settings_key_1.SettingsKey.settingsLinkPreview, newValue);
                        forceUpdate();
                    },
                }));
            }
        }
        return (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(BchatSettingListItem_1.BchatToggleWithDescription, { onClickToggle: () => {
                    handleClick();
                    forceUpdate();
                }, title: "Dark Mode", active: isdark }),
            react_1.default.createElement(BchatSettingListItem_1.BchatToggleWithDescription, { onClickToggle: () => {
                    dispatch((0, userConfig_1.toggleAudioAutoplay)());
                    forceUpdate();
                }, title: window.i18n('audioMessageAutoplayTitle'), description: window.i18n('audioMessageAutoplayDescription'), active: audioAutoPlay }),
            react_1.default.createElement(BchatSettingListItem_1.BchatToggleWithDescription, { onClickToggle: async () => {
                    await toggleLinkPreviews();
                    forceUpdate();
                }, title: window.i18n('linkPreviewsTitle'), description: window.i18n('linkPreviewDescription'), active: isLinkPreviewsOn }),
            os_1.default.platform() !== "darwin" &&
                react_1.default.createElement(BchatSettingListItem_1.BchatToggleWithDescription, { onClickToggle: async () => {
                        await toggleStartInTray();
                        forceUpdate();
                    }, title: window.i18n('startInTrayTitle'), description: "After closing the window, BChat runs in the background", active: isStartInTrayActive }),
            react_1.default.createElement(BchatSettingListItem_1.BchatToggleWithDescription, { onClickToggle: () => {
                    window.toggleSpellCheck();
                    forceUpdate();
                }, title: window.i18n('spellCheckTitle'), description: window.i18n('spellCheckDescription'), active: isSpellCheckActive }),
            react_1.default.createElement(ZoomingBchatSlider_1.ZoomingBchatSlider, null)));
    }
    return null;
};
exports.SettingsCategoryAppearance = SettingsCategoryAppearance;
